@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2007-2009 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, Török Edvin
  *
@@ -22,7 +22,6 @@
 #ifndef __SESSION_H
 #define __SESSION_H
 
-
 #define CMD1 "SCAN"
 /* #define CMD2 "RAWSCAN" */
 #define CMD3 "QUIT" /* deprecated */
@@ -46,13 +45,17 @@
 
 #define CMD21 "ALLMATCHSCAN"
 
+#define CMD22 "GET / HTTP/1.1"
+#define CMD23 "GET / HTTP/2"
+#define CMD24 ""
+
 #include "libclamav/clamav.h"
 #include "shared/optparser.h"
 #include "server.h"
 #include "others.h"
 
 enum commands {
-    COMMAND_UNKNOWN = 0,
+    COMMAND_UNKNOWN  = 0,
     COMMAND_SHUTDOWN = 1,
     COMMAND_RELOAD,
     COMMAND_END,
@@ -74,7 +77,10 @@ enum commands {
     /* internal commands */
     COMMAND_MULTISCANFILE,
     COMMAND_INSTREAMSCAN,
-    COMMAND_ALLMATCHSCAN
+    COMMAND_ALLMATCHSCAN,
+    COMMAND_SYNACK,
+    COMMAND_ACK,
+    COMMAND_GOPHER
 };
 
 typedef struct client_conn_tag {
