@@ -52,87 +52,85 @@ struct optstruct *clamdopts = NULL;
 
 static void print_server_version(const struct optstruct *opt)
 {
-    if(get_clamd_version(opt)) {
-	/* can't get version from server, fallback */
-	printf("ClamAV %s\n", get_version());
+    if (get_clamd_version(opt)) {
+        /* can't get version from server, fallback */
+        printf("ClamAV %s\n", get_version());
     }
 }
 
 int main(int argc, char **argv)
 {
-	int ds, dms, ret, infected = 0, err = 0;
-	struct timeval t1, t2;
-	time_t starttime;
-        struct optstruct *opts;
-        const struct optstruct *opt;
+    int ds, dms, ret, infected = 0, err = 0;
+    struct timeval t1, t2;
+    time_t starttime;
+    struct optstruct *opts;
+    const struct optstruct *opt;
 #ifndef _WIN32
-	struct sigaction sigact;
+    struct sigaction sigact;
 #endif
 
-    if((opts = optparse(NULL, argc, argv, 1, OPT_CLAMDSCAN, OPT_CLAMSCAN, NULL)) == NULL) {
-	mprintf("!Can't parse command line options\n");
-	return 2;
+    if ((opts = optparse(NULL, argc, argv, 1, OPT_CLAMDSCAN, OPT_CLAMSCAN, NULL)) == NULL) {
+        mprintf("!Can't parse command line options\n");
+        return 2;
     }
 
-    if((clamdopts = optparse(optget(opts, "config-file")->strarg, 0, NULL, 1, OPT_CLAMD, 0, NULL)) == NULL) {
-	logg("!Can't parse clamd configuration file %s\n", optget(opts, "config-file")->strarg);
-	return 2;
+    if (optget(opts, "help")->enabled) {
+        optfree(opts);
+        help();
     }
 
-    if(optget(opts, "verbose")->enabled) {
-	mprintf_verbose = 1;
-	logg_verbose = 1;
+    if ((clamdopts = optparse(optget(opts, "config-file")->strarg, 0, NULL, 1, OPT_CLAMD, 0, NULL)) == NULL) {
+        logg("!Can't parse clamd configuration file %s\n", optget(opts, "config-file")->strarg);
+        return 2;
     }
 
-    if(optget(opts, "quiet")->enabled)
-	mprintf_quiet = 1;
-
-    if(optget(opts, "stdout")->enabled)
-	mprintf_stdout = 1;
-
-    if(optget(opts, "version")->enabled) {
-	print_server_version(opts);
-	optfree(opts);
-	optfree(clamdopts);
-	exit(0);
+    if (optget(opts, "verbose")->enabled) {
+        mprintf_verbose = 1;
+        logg_verbose    = 1;
     }
 
-    if(optget(opts, "help")->enabled) {
-	optfree(opts);
-	optfree(clamdopts);
-    	help();
+    if (optget(opts, "quiet")->enabled)
+        mprintf_quiet = 1;
+
+    if (optget(opts, "stdout")->enabled)
+        mprintf_stdout = 1;
+
+    if (optget(opts, "version")->enabled) {
+        print_server_version(opts);
+        optfree(opts);
+        optfree(clamdopts);
+        exit(0);
     }
 
-    if(optget(opts, "infected")->enabled)
-	printinfected = 1;
+    if (optget(opts, "infected")->enabled)
+        printinfected = 1;
 
     /* initialize logger */
 
-    if((opt = optget(opts, "log"))->enabled) {
-	logg_file = opt->strarg;
-	if(logg("--------------------------------------\n")) {
-	    mprintf("!Problem with internal logger.\n");
-	    optfree(opts);
-	    optfree(clamdopts);
-	    exit(2);
-	}
-    } else 
-	logg_file = NULL;
+    if ((opt = optget(opts, "log"))->enabled) {
+        logg_file = opt->strarg;
+        if (logg("--------------------------------------\n")) {
+            mprintf("!Problem with internal logger.\n");
+            optfree(opts);
+            optfree(clamdopts);
+            exit(2);
+        }
+    } else
+        logg_file = NULL;
 
-
-    if(optget(opts, "reload")->enabled) {
-	ret = reload_clamd_database(opts);
-	optfree(opts);
-	optfree(clamdopts);
-	logg_close();
-	exit(ret);
+    if (optget(opts, "reload")->enabled) {
+        ret = reload_clamd_database(opts);
+        optfree(opts);
+        optfree(clamdopts);
+        logg_close();
+        exit(ret);
     }
 
-    if(actsetup(opts)) {
-	optfree(opts);
-	optfree(clamdopts);
-	logg_close();
-	exit(2);
+    if (actsetup(opts)) {
+        optfree(opts);
+        optfree(clamdopts);
+        logg_close();
+        exit(2);
     }
 
 #ifndef _WIN32
@@ -152,28 +150,28 @@ int main(int argc, char **argv)
     optfree(clamdopts);
 
     /* TODO: Implement STATUS in clamd */
-    if(!optget(opts, "no-summary")->enabled) {
-	gettimeofday(&t2, NULL);
-	ds = t2.tv_sec - t1.tv_sec;
-	dms = t2.tv_usec - t1.tv_usec;
-	ds -= (dms < 0) ? (1):(0);
-	dms += (dms < 0) ? (1000000):(0);
-	logg("\n----------- SCAN SUMMARY -----------\n");
-	logg("Infected files: %d\n", infected);
-	if(err)
-	    logg("Total errors: %d\n", err);
-	if(notremoved) {
-	    logg("Not removed: %d\n", notremoved);
-	}
-	if(notmoved) {
-	    logg("Not moved: %d\n", notmoved);
-	}
-	logg("Time: %d.%3.3d sec (%d m %d s)\n", ds, dms/1000, ds/60, ds%60);
+    if (!optget(opts, "no-summary")->enabled) {
+        gettimeofday(&t2, NULL);
+        ds  = t2.tv_sec - t1.tv_sec;
+        dms = t2.tv_usec - t1.tv_usec;
+        ds -= (dms < 0) ? (1) : (0);
+        dms += (dms < 0) ? (1000000) : (0);
+        logg("\n----------- SCAN SUMMARY -----------\n");
+        logg("Infected files: %d\n", infected);
+        if (err)
+            logg("Total errors: %d\n", err);
+        if (notremoved) {
+            logg("Not removed: %d\n", notremoved);
+        }
+        if (notmoved) {
+            logg("Not moved: %d\n", notmoved);
+        }
+        logg("Time: %d.%3.3d sec (%d m %d s)\n", ds, dms / 1000, ds / 60, ds % 60);
     }
 
     logg_close();
     optfree(opts);
-    cl_cleanup_crypto();
+
     exit(ret);
 }
 
@@ -192,7 +190,7 @@ void help(void)
     mprintf("    --version           -V             Print version number and exit\n");
     mprintf("    --verbose           -v             Be verbose\n");
     mprintf("    --quiet                            Be quiet, only output error messages\n");
-    mprintf("    --stdout                           Write to stdout instead of stderr\n");
+    mprintf("    --stdout                           Write to stdout instead of stderr. Does not affect 'debug' messages.\n");
     mprintf("                                       (this help is always written to stdout)\n");
     mprintf("    --log=FILE          -l FILE        Save scan report in FILE\n");
     mprintf("    --file-list=FILE    -f FILE        Scan files from FILE\n");
