@@ -17,12 +17,13 @@
  *  MA 02110-1301, USA.
  */
 
-
 #ifndef __EXECUTE_H
 #define __EXECUTE_H
 
 #include "shared/optparser.h"
 
-void execute( const char *type, const char *text, const struct optstruct *opts );
+extern int g_active_children;
+
+void execute(const char *type, const char *text, int bDaemonized);
 
 #endif
