@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2011 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2011-2013 Sourcefire, Inc.
  *
  *  Authors: aCaB
  *
@@ -42,22 +42,21 @@
 #define OID_2_16_840_1_101_3_4_2_3 "\x60\x86\x48\x01\x65\x03\x04\x02\x03"
 #define OID_sha512 OID_2_16_840_1_101_3_4_2_3
 
-
-int cli_crt_init(cli_crt *x509) {
+int cli_crt_init(cli_crt *x509)
+{
     int ret;
-    if((ret = mp_init_multi(&x509->n, &x509->e, &x509->sig, NULL))) {
+
+    memset(x509, 0, sizeof(*x509));
+
+    if ((ret = mp_init_multi(&x509->n, &x509->e, &x509->sig, NULL))) {
         cli_errmsg("cli_crt_init: mp_init_multi failed with %d\n", ret);
         return 1;
     }
-    x509->name = NULL;
-    x509->isBlacklisted = 0;
-    x509->not_before = x509->not_after = 0;
-    x509->prev = x509->next = NULL;
-    x509->certSign = x509->codeSign = x509->timeSign = 0;
     return 0;
 }
 
-void cli_crt_clear(cli_crt *x509) {
+void cli_crt_clear(cli_crt *x509)
+{
     UNUSEDPARAM(x509);
     mp_clear_multi(&x509->n, &x509->e, &x509->sig, NULL);
 }
@@ -70,42 +69,81 @@ void cli_crt_clear(cli_crt *x509) {
  *
  * There are two ways that things get added to the whitelist - through the CRB
  * rules, and through embedded signatures / catalog files that we parse.  CRB
- * rules only specify the subject, serial, public key, and whether the cert
- * can be used for cert/code/time signing, so in those cases the issuer and
- * hashtype get set to a hardcoded value.  Those values are important for
- * doing signature verification, though, so we include them when doing this
- * lookup.  That way, certs with more specific values can get added to the
- * whitelist by functions like crtmgr_add and increase the probability of
- * successful signature verification. */
-cli_crt *crtmgr_whitelist_lookup(crtmgr *m, cli_crt *x509) {
+ * rules don't currently allow the issuer and hashtype to be specified, so the
+ * code sets those to sentinel values (0xcacacaca repeating and
+ * CLI_HASHTYPE_ANY respectively).  There are two ways we'd like to use this
+ * function:
+ * 
+ *  - To see whether x509 already exists in m (when adding new CRB sig certs
+ *    and when adding certs that are embedded in Authenticode signatures) to
+ *    prevent duplicate entries. In this case, we want to take x509's
+ *    hashtype and issuer field into account, so a CRB sig cert entry isn't
+ *    returned for an embedded cert duplicate check, and so that two embedded
+ *    certs with different hash types or issuers aren't treated as being the
+ *    same.
+ * 
+ *  - To see whether a CRB sig matches against x509, deeming it worthy to be
+ *    added to the trust store.  In this case, we don't want to compare
+ *    hashtype and issuer, since the embedded sig will have the actual values
+ *    and the CRB sig cert will have placeholder values.
+ * 
+ * Use crb_crts_only to distinguish between the two cases.  If True, it will
+ * ignore all crts not added from CRB rules and ignore x509's issuer and
+ * hashtype fields */
+cli_crt *crtmgr_whitelist_lookup(crtmgr *m, cli_crt *x509, int crb_crts_only)
+{
     cli_crt *i;
-    for(i = m->crts; i; i = i->next) {
-        if(!i->isBlacklisted &&
-           x509->not_before >= i->not_before &&
-           x509->not_after <= i->not_after &&
-           (i->certSign | x509->certSign) == i->certSign &&
-           (i->codeSign | x509->codeSign) == i->codeSign &&
-           (i->timeSign | x509->timeSign) == i->timeSign &&
-           !memcmp(x509->subject, i->subject, sizeof(i->subject)) &&
-           !memcmp(x509->serial, i->serial, sizeof(i->serial)) &&
-           !memcmp(x509->issuer, i->issuer, sizeof(i->issuer)) &&
-           x509->hashtype == i->hashtype &&
-           !mp_cmp(&x509->n, &i->n) &&
-           !mp_cmp(&x509->e, &i->e)) {
+    for (i = m->crts; i; i = i->next) {
+
+        if (i->isBlacklisted) {
+            continue;
+        }
+
+        if (crb_crts_only) {
+            if (i->hashtype != CLI_HASHTYPE_ANY) {
+                continue;
+            }
+        } else {
+            /* Almost all of the rules in m will be CRB rules, so optimize for
+             * the case where we are trying to determine whether an embedded
+             * cert already exists in m (by checking the hashtype first). Do
+             * the issuer check here too to simplify the code. */
+
+            if (x509->hashtype != i->hashtype ||
+                memcmp(x509->issuer, i->issuer, sizeof(i->issuer))) {
+                continue;
+            }
+        }
+
+        if (x509->not_before >= i->not_before &&
+            x509->not_after <= i->not_after &&
+            (i->certSign | x509->certSign) == i->certSign &&
+            (i->codeSign | x509->codeSign) == i->codeSign &&
+            (i->timeSign | x509->timeSign) == i->timeSign &&
+            !memcmp(x509->subject, i->subject, sizeof(i->subject)) &&
+            !memcmp(x509->serial, i->serial, sizeof(i->serial)) &&
+            !mp_cmp(&x509->n, &i->n) &&
+            !mp_cmp(&x509->e, &i->e)) {
             return i;
         }
     }
     return NULL;
 }
 
-cli_crt *crtmgr_blacklist_lookup(crtmgr *m, cli_crt *x509) {
+cli_crt *crtmgr_blacklist_lookup(crtmgr *m, cli_crt *x509)
+{
     cli_crt *i;
     for (i = m->crts; i; i = i->next) {
         // The CRB rules are based on subject, serial, and public key,
         // so do blacklist queries based on those fields
 
+        // TODO the rule format specifies CodeSign / TimeSign / CertSign
+        // which we could also match on, but we just ignore those fields
+        // for blacklist certs for now
+
         // TODO Handle the case where these items aren't specified in a CRB
-        // rule entry - substitute in default values instead.
+        // rule entry - substitute in default values instead (or make the
+        // crb parser not permit leaving these fields blank).
 
         if (i->isBlacklisted &&
             !memcmp(i->subject, x509->subject, sizeof(i->subject)) &&
@@ -120,15 +158,17 @@ cli_crt *crtmgr_blacklist_lookup(crtmgr *m, cli_crt *x509) {
 
 /* Determine whether x509 already exists in m. The fields compared depend on
  * whether x509 is a blacklist entry or a trusted certificate */
-cli_crt *crtmgr_lookup(crtmgr *m, cli_crt *x509) {
+cli_crt *crtmgr_lookup(crtmgr *m, cli_crt *x509)
+{
     if (x509->isBlacklisted) {
         return crtmgr_blacklist_lookup(m, x509);
     } else {
-        return crtmgr_whitelist_lookup(m, x509);
+        return crtmgr_whitelist_lookup(m, x509, 0);
     }
 }
 
-int crtmgr_add(crtmgr *m, cli_crt *x509) {
+int crtmgr_add(crtmgr *m, cli_crt *x509)
+{
     cli_crt *i;
     int ret = 0;
 
@@ -138,22 +178,22 @@ int crtmgr_add(crtmgr *m, cli_crt *x509) {
             return 0;
         }
     } else {
-        if (crtmgr_whitelist_lookup(m, x509)) {
+        if (crtmgr_whitelist_lookup(m, x509, 0)) {
             cli_dbgmsg("crtmgr_add: duplicate trusted certificate detected - not adding\n");
             return 0;
         }
     }
 
     i = cli_malloc(sizeof(*i));
-    if(!i)
+    if (!i)
         return 1;
 
-    if((ret = mp_init_multi(&i->n, &i->e, &i->sig, NULL))) {
+    if ((ret = mp_init_multi(&i->n, &i->e, &i->sig, NULL))) {
         cli_warnmsg("crtmgr_add: failed to mp_init failed with %d\n", ret);
         free(i);
         return 1;
     }
-    if((ret = mp_copy(&x509->n, &i->n)) || (ret = mp_copy(&x509->e, &i->e)) || (ret = mp_copy(&x509->sig, &i->sig))) {
+    if ((ret = mp_copy(&x509->n, &i->n)) || (ret = mp_copy(&x509->e, &i->e)) || (ret = mp_copy(&x509->sig, &i->sig))) {
         cli_warnmsg("crtmgr_add: failed to mp_init failed with %d\n", ret);
         cli_crt_clear(i);
         free(i);
@@ -172,16 +212,16 @@ int crtmgr_add(crtmgr *m, cli_crt *x509) {
     memcpy(i->serial, x509->serial, sizeof(i->serial));
     memcpy(i->issuer, x509->issuer, sizeof(i->issuer));
     memcpy(i->tbshash, x509->tbshash, sizeof(i->tbshash));
-    i->not_before = x509->not_before;
-    i->not_after = x509->not_after;
-    i->hashtype = x509->hashtype;
-    i->certSign = x509->certSign;
-    i->codeSign = x509->codeSign;
-    i->timeSign = x509->timeSign;
+    i->not_before    = x509->not_before;
+    i->not_after     = x509->not_after;
+    i->hashtype      = x509->hashtype;
+    i->certSign      = x509->certSign;
+    i->codeSign      = x509->codeSign;
+    i->timeSign      = x509->timeSign;
     i->isBlacklisted = x509->isBlacklisted;
-    i->next = m->crts;
-    i->prev = NULL;
-    if(m->crts)
+    i->next          = m->crts;
+    i->prev          = NULL;
+    if (m->crts)
         m->crts->prev = i;
     m->crts = i;
 
@@ -189,20 +229,22 @@ int crtmgr_add(crtmgr *m, cli_crt *x509) {
     return 0;
 }
 
-void crtmgr_init(crtmgr *m) {
-    m->crts = NULL;
+void crtmgr_init(crtmgr *m)
+{
+    m->crts  = NULL;
     m->items = 0;
 }
 
-void crtmgr_del(crtmgr *m, cli_crt *x509) {
+void crtmgr_del(crtmgr *m, cli_crt *x509)
+{
     cli_crt *i;
-    for(i = m->crts; i; i = i->next) {
-        if(i==x509) {
-            if(i->prev)
+    for (i = m->crts; i; i = i->next) {
+        if (i == x509) {
+            if (i->prev)
                 i->prev->next = i->next;
             else
                 m->crts = i->next;
-            if(i->next)
+            if (i->next)
                 i->next->prev = i->prev;
             cli_crt_clear(x509);
             if ((x509->name))
@@ -214,12 +256,14 @@ void crtmgr_del(crtmgr *m, cli_crt *x509) {
     }
 }
 
-void crtmgr_free(crtmgr *m) {
-    while(m->items)
+void crtmgr_free(crtmgr *m)
+{
+    while (m->items)
         crtmgr_del(m, m->crts);
 }
 
-static int crtmgr_rsa_verify(cli_crt *x509, mp_int *sig, cli_crt_hashtype hashtype, const uint8_t *refhash) {
+static int crtmgr_rsa_verify(cli_crt *x509, mp_int *sig, cli_crt_hashtype hashtype, const uint8_t *refhash)
+{
     int keylen = mp_unsigned_bin_size(&x509->n), siglen = mp_unsigned_bin_size(sig);
     int ret, j, objlen, hashlen;
     uint8_t d[513];
@@ -240,46 +284,46 @@ static int crtmgr_rsa_verify(cli_crt *x509, mp_int *sig, cli_crt_hashtype hashty
         return 1;
     }
 
-    if((ret = mp_init(&x))) {
+    if ((ret = mp_init(&x))) {
         cli_errmsg("crtmgr_rsa_verify: mp_init failed with %d\n", ret);
         return 1;
     }
 
     do {
-        if(MAX(keylen, siglen) - MIN(keylen, siglen) > 1) {
+        if (MAX(keylen, siglen) - MIN(keylen, siglen) > 1) {
             cli_dbgmsg("crtmgr_rsa_verify: keylen and siglen differ by more than one\n");
             break;
         }
-        if((ret = mp_exptmod(sig, &x509->e, &x509->n, &x))) {
+        if ((ret = mp_exptmod(sig, &x509->e, &x509->n, &x))) {
             cli_warnmsg("crtmgr_rsa_verify: verification failed: mp_exptmod failed with %d\n", ret);
             break;
         }
-        if(mp_unsigned_bin_size(&x) != keylen - 1){
+        if (mp_unsigned_bin_size(&x) != keylen - 1) {
             cli_dbgmsg("crtmgr_rsa_verify: keylen-1 doesn't match expected size of exptmod result\n");
             break;
         }
-        if(((unsigned int) mp_unsigned_bin_size(&x)) > sizeof(d)) {
+        if (((unsigned int)mp_unsigned_bin_size(&x)) > sizeof(d)) {
             cli_dbgmsg("crtmgr_rsa_verify: exptmod result would overrun working buffer\n");
             break;
         }
-        if((ret = mp_to_unsigned_bin(&x, d))) {
+        if ((ret = mp_to_unsigned_bin(&x, d))) {
             cli_warnmsg("crtmgr_rsa_verify: mp_unsigned_bin_size failed with %d\n", ret);
             break;
         }
-        if(*d != 1) {/* block type 1 */
+        if (*d != 1) { /* block type 1 */
             cli_dbgmsg("crtmgr_rsa_verify: expected block type 1 at d[0]\n");
             break;
         }
 
         keylen -= 1; /* 0xff padding */
-        for(j=1; j<keylen-2; j++)
-            if(d[j] != 0xff)
+        for (j = 1; j < keylen - 2; j++)
+            if (d[j] != 0xff)
                 break;
-        if(j == keylen - 2) {
+        if (j == keylen - 2) {
             cli_dbgmsg("crtmgr_rsa_verify: only encountered 0xFF padding parsing cert\n");
             break;
         }
-        if(d[j] != 0) { /* 0x00 separator */
+        if (d[j] != 0) { /* 0x00 separator */
             cli_dbgmsg("crtmgr_rsa_verify: expected 0x00 separator\n");
             break;
         }
@@ -287,46 +331,46 @@ static int crtmgr_rsa_verify(cli_crt *x509, mp_int *sig, cli_crt_hashtype hashty
         j++;
         keylen -= j; /* asn1 size */
 
-        if(keylen < hashlen) {
+        if (keylen < hashlen) {
             cli_dbgmsg("crtmgr_rsa_verify: encountered keylen less than hashlen\n");
             break;
         }
-        if(keylen > hashlen) {
+        if (keylen > hashlen) {
             /* hash is asn1 der encoded */
             /* SEQ { SEQ { OID, NULL }, OCTET STRING */
-            if(keylen < 2 || d[j] != 0x30 || d[j+1] + 2 != keylen) {
+            if (keylen < 2 || d[j] != 0x30 || d[j + 1] + 2 != keylen) {
                 cli_dbgmsg("crtmgr_rsa_verify: unexpected hash to be ASN1 DER encoded\n");
                 break;
             }
             keylen -= 2;
-            j+=2;
+            j += 2;
 
-            if(keylen <2 || d[j] != 0x30) {
+            if (keylen < 2 || d[j] != 0x30) {
                 cli_dbgmsg("crtmgr_rsa_verify: expected SEQUENCE at beginning of cert AlgorithmIdentifier\n");
                 break;
             }
 
-            objlen = d[j+1];
+            objlen = d[j + 1];
 
             keylen -= 2;
-            j+=2;
-            if(keylen < objlen) {
+            j += 2;
+            if (keylen < objlen) {
                 cli_dbgmsg("crtmgr_rsa_verify: key length mismatch in ASN1 DER hash encoding\n");
                 break;
             }
-            if(objlen == 9) {
+            if (objlen == 9) {
                 // Check for OID type indicating a length of 5, OID_sha1, and the NULL type/value
-                if(hashtype != CLI_SHA1RSA || memcmp(&d[j], "\x06\x05" OID_sha1 "\x05\x00", 9)) {
+                if (hashtype != CLI_SHA1RSA || memcmp(&d[j], "\x06\x05" OID_sha1 "\x05\x00", 9)) {
                     cli_errmsg("crtmgr_rsa_verify: FIXME ACAB - CRYPTO MISSING?\n");
                     break;
                 }
-            } else if(objlen == 12) {
+            } else if (objlen == 12) {
                 // Check for OID type indicating a length of 8, OID_md5, and the NULL type/value
-                if(hashtype != CLI_MD5RSA || memcmp(&d[j], "\x06\x08" OID_md5 "\x05\x00", 12)) {
+                if (hashtype != CLI_MD5RSA || memcmp(&d[j], "\x06\x08" OID_md5 "\x05\x00", 12)) {
                     cli_errmsg("crtmgr_rsa_verify: FIXME ACAB - CRYPTO MISSING?\n");
                     break;
                 }
-            } else if(objlen == 13) {
+            } else if (objlen == 13) {
                 if (hashtype == CLI_SHA256RSA) {
                     // Check for OID type indicating a length of 9, OID_sha256, and the NULL type/value
                     if (0 != memcmp(&d[j], "\x06\x09" OID_sha256 "\x05\x00", 13)) {
@@ -359,18 +403,18 @@ static int crtmgr_rsa_verify(cli_crt *x509, mp_int *sig, cli_crt_hashtype hashty
 
             keylen -= objlen;
             j += objlen;
-            if(keylen < 2 || d[j] != 0x04 || d[j+1] != hashlen) {
+            if (keylen < 2 || d[j] != 0x04 || d[j + 1] != hashlen) {
                 cli_dbgmsg("crtmgr_rsa_verify: hash length mismatch in ASN1 DER hash encoding\n");
                 break;
             }
             keylen -= 2;
-            j+=2;
-            if(keylen != hashlen) {
+            j += 2;
+            if (keylen != hashlen) {
                 cli_dbgmsg("crtmgr_rsa_verify: extra data in the ASN1 DER hash encoding\n");
                 break;
             }
         }
-        if(memcmp(&d[j], refhash, hashlen)) {
+        if (memcmp(&d[j], refhash, hashlen)) {
             // This is a common error case if we are using crtmgr_rsa_verify to
             // determine whether we've found the right issuer certificate based
             // (as is done by crtmgr_verify_crt).  If we are pretty sure that
@@ -382,44 +426,44 @@ static int crtmgr_rsa_verify(cli_crt *x509, mp_int *sig, cli_crt_hashtype hashty
         mp_clear(&x);
         return 0;
 
-    } while(0);
+    } while (0);
 
     mp_clear(&x);
     return 1;
 }
 
-/* For a given cli_crt, returns an existing blacklisted cert in crtmgr if one
- * is present.  Otherwise returns a pointer to the signer x509 certificate if
+/* For a given cli_crt, returns a pointer to the signer x509 certificate if
  * one is found in the crtmgr and it's signature can be validated (NULL is
  * returned otherwise.) */
-cli_crt *crtmgr_verify_crt(crtmgr *m, cli_crt *x509) {
+cli_crt *crtmgr_verify_crt(crtmgr *m, cli_crt *x509)
+{
     cli_crt *i = m->crts, *best = NULL;
-    int score = 0;
+    int score             = 0;
     unsigned int possible = 0;
 
-    if (NULL != (i = crtmgr_blacklist_lookup(m, x509))) {
-        return i;
-    }
+    // Loop through each of the certificates in our trust store and see whether
+    // x509 is signed with it.  If it is, it's trusted
 
     // TODO Technically we should loop through all of the blacklisted certs
     // first to see whether one of those is used to sign x509.  This case
     // will get handled if the blacklisted certificate is embedded, since we
     // will call crtmgr_verify_crt on it and match against the blacklist entry
     // that way, but the cert doesn't HAVE to be embedded.  This case seems
-    // unlikely enough to ignore, though.
+    // unlikely enough to ignore, though.  If we ever want to blacklist a
+    // stolen CA cert or something, then we will need to revisit this.
 
-    for(i = m->crts; i; i = i->next) {
-        if(i->certSign &&
-           !i->isBlacklisted &&
-           !memcmp(i->subject, x509->issuer, sizeof(i->subject)) &&
-           !crtmgr_rsa_verify(i, &x509->sig, x509->hashtype, x509->tbshash)) {
+    for (i = m->crts; i; i = i->next) {
+        if (i->certSign &&
+            !i->isBlacklisted &&
+            !memcmp(i->subject, x509->issuer, sizeof(i->subject)) &&
+            !crtmgr_rsa_verify(i, &x509->sig, x509->hashtype, x509->tbshash)) {
             int curscore;
-            if((x509->codeSign & i->codeSign) == x509->codeSign && (x509->timeSign & i->timeSign) == x509->timeSign)
+            if ((x509->codeSign & i->codeSign) == x509->codeSign && (x509->timeSign & i->timeSign) == x509->timeSign)
                 return i;
             possible++;
             curscore = (x509->codeSign & i->codeSign) + (x509->timeSign & i->timeSign);
-            if(curscore > score) {
-                best = i;
+            if (curscore > score) {
+                best  = i;
                 score = curscore;
             }
         }
@@ -433,33 +477,34 @@ cli_crt *crtmgr_verify_crt(crtmgr *m, cli_crt *x509) {
     return best;
 }
 
-cli_crt *crtmgr_verify_pkcs7(crtmgr *m, const uint8_t *issuer, const uint8_t *serial, const void *signature, unsigned int signature_len, cli_crt_hashtype hashtype, const uint8_t *refhash, cli_vrfy_type vrfytype) {
+cli_crt *crtmgr_verify_pkcs7(crtmgr *m, const uint8_t *issuer, const uint8_t *serial, const void *signature, unsigned int signature_len, cli_crt_hashtype hashtype, const uint8_t *refhash, cli_vrfy_type vrfytype)
+{
     cli_crt *i;
     mp_int sig;
     int ret;
 
-    if(signature_len < 1024/8 || signature_len > 4096/8+1) {
+    if (signature_len < 1024 / 8 || signature_len > 4096 / 8 + 1) {
         cli_dbgmsg("crtmgr_verify_pkcs7: unsupported sig len: %u\n", signature_len);
         return NULL;
     }
-    if((ret = mp_init(&sig))) {
+    if ((ret = mp_init(&sig))) {
         cli_dbgmsg("crtmgr_verify_pkcs7: mp_init failed with %d\n", ret);
         return NULL;
     }
 
-    if((ret=mp_read_unsigned_bin(&sig, signature, signature_len))) {
+    if ((ret = mp_read_unsigned_bin(&sig, signature, signature_len))) {
         cli_dbgmsg("crtmgr_verify_pkcs7: mp_read_unsigned_bin failed with %d\n", ret);
         return NULL;
     }
 
-    for(i = m->crts; i; i = i->next) {
-        if(vrfytype == VRFY_CODE && !i->codeSign)
+    for (i = m->crts; i; i = i->next) {
+        if (vrfytype == VRFY_CODE && !i->codeSign)
             continue;
-        if(vrfytype == VRFY_TIME && !i->timeSign)
+        if (vrfytype == VRFY_TIME && !i->timeSign)
             continue;
-        if(!memcmp(i->issuer, issuer, sizeof(i->issuer)) &&
-           !memcmp(i->serial, serial, sizeof(i->serial))) {
-            if(!crtmgr_rsa_verify(i, &sig, hashtype, refhash)) {
+        if (!memcmp(i->issuer, issuer, sizeof(i->issuer)) &&
+            !memcmp(i->serial, serial, sizeof(i->serial))) {
+            if (!crtmgr_rsa_verify(i, &sig, hashtype, refhash)) {
                 break;
             }
             cli_dbgmsg("crtmgr_verify_pkcs7: found cert with matching issuer and serial but RSA verification failed\n");
@@ -469,20 +514,24 @@ cli_crt *crtmgr_verify_pkcs7(crtmgr *m, const uint8_t *issuer, const uint8_t *se
     return i;
 }
 
-int crtmgr_add_roots(struct cl_engine *engine, crtmgr *m) {
+int crtmgr_add_roots(struct cl_engine *engine, crtmgr *m, int exclude_bl_crts)
+{
     cli_crt *crt;
     /*
      * Certs are cached in engine->cmgr. Copy from there.
      */
     if (m != &(engine->cmgr)) {
-       for (crt = engine->cmgr.crts; crt != NULL; crt = crt->next) {
-           if (crtmgr_add(m, crt)) {
-               crtmgr_free(m);
-               return 1;
-           }
-       }
+        for (crt = engine->cmgr.crts; crt != NULL; crt = crt->next) {
+            if (exclude_bl_crts && crt->isBlacklisted) {
+                continue;
+            }
+            if (crtmgr_add(m, crt)) {
+                crtmgr_free(m);
+                return 1;
+            }
+        }
 
-       return 0;
+        return 0;
     }
 
     return 0;
