@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2011 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2011-2013 Sourcefire, Inc.
  *
  *  Authors: aCaB
  *
@@ -26,10 +26,21 @@
 
 #include "bignum.h"
 
-typedef enum {CLI_SHA1RSA, CLI_MD5RSA, CLI_MD2RSA, CLI_RSA, CLI_SHA256RSA, CLI_SHA384RSA, CLI_SHA512RSA } cli_crt_hashtype;
-typedef enum {VRFY_CODE, VRFY_TIME} cli_vrfy_type;
+typedef enum { CLI_HASHTYPE_ANY, /* used by crts added from .CRB rules */
+               CLI_SHA1RSA,
+               CLI_MD5RSA,
+               CLI_MD2RSA,
+               CLI_RSA,
+               CLI_SHA256RSA,
+               CLI_SHA384RSA,
+               CLI_SHA512RSA } cli_crt_hashtype;
+typedef enum { VRFY_CODE,
+               VRFY_TIME } cli_vrfy_type;
 
+#ifndef CRT_RAWMAXLEN
 #define CRT_RAWMAXLEN 64
+#endif
+
 typedef struct cli_crt_t {
     char *name;
     uint8_t raw_subject[CRT_RAWMAXLEN];
@@ -61,17 +72,17 @@ typedef struct {
     unsigned int items;
 } crtmgr;
 
-
 int cli_crt_init(cli_crt *x509);
 void cli_crt_clear(cli_crt *x509);
 void crtmgr_init(crtmgr *m);
 void crtmgr_free(crtmgr *m);
 int crtmgr_add(crtmgr *m, cli_crt *x509);
 cli_crt *crtmgr_lookup(crtmgr *m, cli_crt *x509);
+cli_crt *crtmgr_blacklist_lookup(crtmgr *m, cli_crt *x509);
+cli_crt *crtmgr_whitelist_lookup(crtmgr *m, cli_crt *x509, int crb_crts_only);
 void crtmgr_del(crtmgr *m, cli_crt *x509);
 cli_crt *crtmgr_verify_crt(crtmgr *m, cli_crt *x509);
 cli_crt *crtmgr_verify_pkcs7(crtmgr *m, const uint8_t *issuer, const uint8_t *serial, const void *signature, unsigned int signature_len, cli_crt_hashtype hashtype, const uint8_t *refhash, cli_vrfy_type vrfytype);
-int crtmgr_add_roots(struct cl_engine *engine, crtmgr *m);
-
+int crtmgr_add_roots(struct cl_engine *engine, crtmgr *m, int exclude_bl_crts);
 
 #endif
