@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2007-2009 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm
  *
@@ -24,11 +24,11 @@
 
 #include "matcher.h"
 #include "filetypes.h"
-#include "cltypes.h"
+#include "clamav-types.h"
 #include "fmap.h"
 #include "others.h"
 
-#define BM_BOUNDARY_EOL	1
+#define BM_BOUNDARY_EOL 1
 
 struct cli_bm_patt {
     unsigned char *pattern, *prefix;
@@ -45,11 +45,11 @@ struct cli_bm_off {
     uint32_t *offset, *offtab, cnt, pos;
 };
 
-int cli_bm_addpatt(struct cli_matcher *root, struct cli_bm_patt *pattern, const char *offset);
-int cli_bm_init(struct cli_matcher *root);
-int cli_bm_initoff(const struct cli_matcher *root, struct cli_bm_off *data, const struct cli_target_info *info);
+cl_error_t cli_bm_addpatt(struct cli_matcher *root, struct cli_bm_patt *pattern, const char *offset);
+cl_error_t cli_bm_init(struct cli_matcher *root);
+cl_error_t cli_bm_initoff(const struct cli_matcher *root, struct cli_bm_off *data, const struct cli_target_info *info);
 void cli_bm_freeoff(struct cli_bm_off *data);
-int cli_bm_scanbuff(const unsigned char *buffer, uint32_t length, const char **virname, const struct cli_bm_patt **patt, const struct cli_matcher *root, uint32_t offset, const struct cli_target_info *info, struct cli_bm_off *offdata, cli_ctx *ctx);
+cl_error_t cli_bm_scanbuff(const unsigned char *buffer, uint32_t length, const char **virname, const struct cli_bm_patt **patt, const struct cli_matcher *root, uint32_t offset, const struct cli_target_info *info, struct cli_bm_off *offdata, cli_ctx *ctx);
 void cli_bm_free(struct cli_matcher *root);
 
 #endif
