@@ -51,7 +51,7 @@
 #include "crtmgr.h"
 
 #ifdef HAVE_JSON
-#include "json.h"
+#include "json-c/json.h"
 #endif
 
 #ifdef HAVE_YARA
@@ -71,8 +71,8 @@
  * in re-enabling affected modules.
  */
 
-#define CL_FLEVEL 105
-#define CL_FLEVEL_DCONF	CL_FLEVEL
+#define CL_FLEVEL 111
+#define CL_FLEVEL_DCONF CL_FLEVEL
 #define CL_FLEVEL_SIGTOOL CL_FLEVEL
 
 extern uint8_t cli_debug_flag;
@@ -94,8 +94,7 @@ extern uint8_t cli_always_gen_section_hash;
         (ptrdiff_t)(sb) >= (ptrdiff_t)(bb) &&                                               \
         (ptrdiff_t)(sb) + (ptrdiff_t)(sb_size) <= (ptrdiff_t)(bb) + (ptrdiff_t)(bb_size) && \
         (ptrdiff_t)(sb) + (ptrdiff_t)(sb_size) > (ptrdiff_t)(bb) &&                         \
-        (ptrdiff_t)(sb) < (ptrdiff_t)(bb) + (ptrdiff_t)(bb_size)                            \
-    )
+        (ptrdiff_t)(sb) < (ptrdiff_t)(bb) + (ptrdiff_t)(bb_size))
 
 /*
  * CLI_ISCONTAINED2(bb, bb_size, sb, sb_size) checks if sb (sub buffer) is contained
@@ -111,26 +110,25 @@ extern uint8_t cli_always_gen_section_hash;
         (ptrdiff_t)(sb) >= (ptrdiff_t)(bb) &&                                               \
         (ptrdiff_t)(sb) + (ptrdiff_t)(sb_size) <= (ptrdiff_t)(bb) + (ptrdiff_t)(bb_size) && \
         (ptrdiff_t)(sb) + (ptrdiff_t)(sb_size) >= (ptrdiff_t)(bb) &&                        \
-        (ptrdiff_t)(sb) < (ptrdiff_t)(bb) + (ptrdiff_t)(bb_size)                            \
-    )
+        (ptrdiff_t)(sb) < (ptrdiff_t)(bb) + (ptrdiff_t)(bb_size))
 
-#define CLI_MAX_ALLOCATION (182*1024*1024)
+#define CLI_MAX_ALLOCATION (182 * 1024 * 1024)
 
-#ifdef	HAVE_SYS_PARAM_H
-#include <sys/param.h>	/* for NAME_MAX */
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h> /* for NAME_MAX */
 #endif
 
 /* Maximum filenames under various systems - njh */
-#ifndef	NAME_MAX	/* e.g. Linux */
-# ifdef	MAXNAMELEN	/* e.g. Solaris */
-#   define	NAME_MAX	MAXNAMELEN
-# else
-#   ifdef	FILENAME_MAX	/* e.g. SCO */
-#     define	NAME_MAX	FILENAME_MAX
-#   else
-#     define    NAME_MAX        256
-#   endif
-# endif
+#ifndef NAME_MAX  /* e.g. Linux */
+#ifdef MAXNAMELEN /* e.g. Solaris */
+#define NAME_MAX MAXNAMELEN
+#else
+#ifdef FILENAME_MAX /* e.g. SCO */
+#define NAME_MAX FILENAME_MAX
+#else
+#define NAME_MAX 256
+#endif
+#endif
 #endif
 
 #if NAME_MAX < 256
@@ -138,10 +136,9 @@ extern uint8_t cli_always_gen_section_hash;
 #define NAME_MAX 256
 #endif
 
-typedef struct bitset_tag
-{
-        unsigned char *bitset;
-        unsigned long length;
+typedef struct bitset_tag {
+    unsigned char *bitset;
+    unsigned long length;
 } bitset_t;
 
 typedef struct cli_ctx_container_tag {
@@ -171,9 +168,9 @@ typedef struct cli_ctx_tag {
     unsigned char handlertype_hash[16];
     struct cli_dconf *dconf;
     fmap_t **fmap;
-    bitset_t* hook_lsig_matches;
+    bitset_t *hook_lsig_matches;
     void *cb_ctx;
-    cli_events_t* perf;
+    cli_events_t *perf;
 #ifdef HAVE__INTERNAL__SHA_COLLECT
     int sha_collect;
 #endif
@@ -187,7 +184,7 @@ typedef struct cli_ctx_tag {
 
 #define STATS_ANON_UUID "5b585e8f-3be5-11e3-bf0b-18037319526c"
 #define STATS_MAX_SAMPLES 50
-#define STATS_MAX_MEM 1024*1024
+#define STATS_MAX_MEM 1024 * 1024
 
 typedef struct cli_flagged_sample {
     char **virus_name;
@@ -215,7 +212,9 @@ typedef struct cli_clamav_intel {
 #endif
 } cli_intel_t;
 
-typedef struct {uint64_t v[2][4];} icon_groupset;
+typedef struct {
+    uint64_t v[2][4];
+} icon_groupset;
 
 struct icomtr {
     unsigned int group[2];
@@ -286,17 +285,17 @@ struct cl_engine {
     uint64_t engine_options;
 
     /* Limits */
-    uint32_t maxscantime;  /* Time limit (in milliseconds) */
-    uint64_t maxscansize;  /* during the scanning of archives this size
-				     * will never be exceeded
-				     */
-    uint64_t maxfilesize;  /* compressed files will only be decompressed
-				     * and scanned up to this size
-				     */
-    uint32_t maxreclevel;	    /* maximum recursion level for archives */
-    uint32_t maxfiles;	    /* maximum number of files to be scanned
-				     * within a single archive
-				     */
+    uint32_t maxscantime; /* Time limit (in milliseconds) */
+    uint64_t maxscansize; /* during the scanning of archives this size
+				           * will never be exceeded
+				           */
+    uint64_t maxfilesize; /* compressed files will only be decompressed
+				           * and scanned up to this size
+				           */
+    uint32_t maxreclevel; /* maximum recursion level for archives */
+    uint32_t maxfiles;    /* maximum number of files to be scanned
+				           * within a single archive
+				           */
     /* This is for structured data detection.  You can set the minimum
      * number of occurrences of an CC# or SSN before the system will
      * generate a notification.
@@ -316,7 +315,6 @@ struct cl_engine {
     /* hash matcher for whitelist db */
     struct cli_matcher *hm_fp;
 
-
     /* Container metadata */
     struct cli_cdb *cdb;
 
@@ -382,11 +380,11 @@ struct cl_engine {
     enum bytecode_mode bytecode_mode;
 
     /* Engine max settings */
-    uint64_t maxembeddedpe;  /* max size to scan MSEXE for PE */
-    uint64_t maxhtmlnormalize; /* max size to normalize HTML */
-    uint64_t maxhtmlnotags; /* max size for scanning normalized HTML */
+    uint64_t maxembeddedpe;      /* max size to scan MSEXE for PE */
+    uint64_t maxhtmlnormalize;   /* max size to normalize HTML */
+    uint64_t maxhtmlnotags;      /* max size for scanning normalized HTML */
     uint64_t maxscriptnormalize; /* max size to normalize scripts */
-    uint64_t maxziptypercg; /* max size to re-do zip filetype */
+    uint64_t maxziptypercg;      /* max size to re-do zip filetype */
 
     /* Statistics/intelligence gathering */
     void *stats_data;
@@ -413,7 +411,7 @@ struct cl_engine {
 
 #ifdef HAVE_YARA
     /* YARA */
-    struct _yara_global * yara_global;
+    struct _yara_global *yara_global;
 #endif
 };
 
@@ -453,11 +451,11 @@ struct cl_settings {
     clcb_file_props cb_file_props;
 
     /* Engine max settings */
-    uint64_t maxembeddedpe;  /* max size to scan MSEXE for PE */
-    uint64_t maxhtmlnormalize; /* max size to normalize HTML */
-    uint64_t maxhtmlnotags; /* max size for scanning normalized HTML */
+    uint64_t maxembeddedpe;      /* max size to scan MSEXE for PE */
+    uint64_t maxhtmlnormalize;   /* max size to normalize HTML */
+    uint64_t maxhtmlnotags;      /* max size for scanning normalized HTML */
     uint64_t maxscriptnormalize; /* max size to normalize scripts */
-    uint64_t maxziptypercg; /* max size to re-do zip filetype */
+    uint64_t maxziptypercg;      /* max size to re-do zip filetype */
 
     /* Statistics/intelligence gathering */
     void *stats_data;
@@ -485,58 +483,57 @@ struct cl_settings {
 
 extern cl_unrar_error_t (*cli_unrar_open)(const char *filename, void **hArchive, char **comment, uint32_t *comment_size, uint8_t debug_flag);
 extern cl_unrar_error_t (*cli_unrar_peek_file_header)(void *hArchive, unrar_metadata_t *file_metadata);
-extern cl_unrar_error_t (*cli_unrar_extract_file)(void* hArchive, const char* destPath, char *outputBuffer);
+extern cl_unrar_error_t (*cli_unrar_extract_file)(void *hArchive, const char *destPath, char *outputBuffer);
 extern cl_unrar_error_t (*cli_unrar_skip_file)(void *hArchive);
 extern void (*cli_unrar_close)(void *hArchive);
 
 extern int have_rar;
 
-#define SCAN_ALLMATCHES                         (ctx->options->general & CL_SCAN_GENERAL_ALLMATCHES)
-#define SCAN_COLLECT_METADATA                   (ctx->options->general & CL_SCAN_GENERAL_COLLECT_METADATA)
-#define SCAN_HEURISTICS                         (ctx->options->general & CL_SCAN_GENERAL_HEURISTICS)
-#define SCAN_HEURISTIC_PRECEDENCE               (ctx->options->general & CL_SCAN_GENERAL_HEURISTIC_PRECEDENCE)
-#define SCAN_UNPRIVILEGED                       (ctx->options->general & CL_SCAN_GENERAL_UNPRIVILEGED)
+#define SCAN_ALLMATCHES (ctx->options->general & CL_SCAN_GENERAL_ALLMATCHES)
+#define SCAN_COLLECT_METADATA (ctx->options->general & CL_SCAN_GENERAL_COLLECT_METADATA)
+#define SCAN_HEURISTICS (ctx->options->general & CL_SCAN_GENERAL_HEURISTICS)
+#define SCAN_HEURISTIC_PRECEDENCE (ctx->options->general & CL_SCAN_GENERAL_HEURISTIC_PRECEDENCE)
 
-#define SCAN_PARSE_ARCHIVE                      (ctx->options->parse & CL_SCAN_PARSE_ARCHIVE)
-#define SCAN_PARSE_ELF                          (ctx->options->parse & CL_SCAN_PARSE_ELF)
-#define SCAN_PARSE_PDF                          (ctx->options->parse & CL_SCAN_PARSE_PDF)
-#define SCAN_PARSE_SWF                          (ctx->options->parse & CL_SCAN_PARSE_SWF)
-#define SCAN_PARSE_HWP3                         (ctx->options->parse & CL_SCAN_PARSE_HWP3)
-#define SCAN_PARSE_XMLDOCS                      (ctx->options->parse & CL_SCAN_PARSE_XMLDOCS)
-#define SCAN_PARSE_MAIL                         (ctx->options->parse & CL_SCAN_PARSE_MAIL)
-#define SCAN_PARSE_OLE2                         (ctx->options->parse & CL_SCAN_PARSE_OLE2)
-#define SCAN_PARSE_HTML                         (ctx->options->parse & CL_SCAN_PARSE_HTML)
-#define SCAN_PARSE_PE                           (ctx->options->parse & CL_SCAN_PARSE_PE)
+#define SCAN_PARSE_ARCHIVE (ctx->options->parse & CL_SCAN_PARSE_ARCHIVE)
+#define SCAN_PARSE_ELF (ctx->options->parse & CL_SCAN_PARSE_ELF)
+#define SCAN_PARSE_PDF (ctx->options->parse & CL_SCAN_PARSE_PDF)
+#define SCAN_PARSE_SWF (ctx->options->parse & CL_SCAN_PARSE_SWF)
+#define SCAN_PARSE_HWP3 (ctx->options->parse & CL_SCAN_PARSE_HWP3)
+#define SCAN_PARSE_XMLDOCS (ctx->options->parse & CL_SCAN_PARSE_XMLDOCS)
+#define SCAN_PARSE_MAIL (ctx->options->parse & CL_SCAN_PARSE_MAIL)
+#define SCAN_PARSE_OLE2 (ctx->options->parse & CL_SCAN_PARSE_OLE2)
+#define SCAN_PARSE_HTML (ctx->options->parse & CL_SCAN_PARSE_HTML)
+#define SCAN_PARSE_PE (ctx->options->parse & CL_SCAN_PARSE_PE)
 
-#define SCAN_HEURISTIC_BROKEN                   (ctx->options->heuristic & CL_SCAN_HEURISTIC_BROKEN)
-#define SCAN_HEURISTIC_EXCEEDS_MAX              (ctx->options->heuristic & CL_SCAN_HEURISTIC_EXCEEDS_MAX)
-#define SCAN_HEURISTIC_PHISHING_SSL_MISMATCH    (ctx->options->heuristic & CL_SCAN_HEURISTIC_PHISHING_SSL_MISMATCH)
-#define SCAN_HEURISTIC_PHISHING_CLOAK           (ctx->options->heuristic & CL_SCAN_HEURISTIC_PHISHING_CLOAK)
-#define SCAN_HEURISTIC_MACROS                   (ctx->options->heuristic & CL_SCAN_HEURISTIC_MACROS)
-#define SCAN_HEURISTIC_ENCRYPTED_ARCHIVE        (ctx->options->heuristic & CL_SCAN_HEURISTIC_ENCRYPTED_ARCHIVE)
-#define SCAN_HEURISTIC_ENCRYPTED_DOC            (ctx->options->heuristic & CL_SCAN_HEURISTIC_ENCRYPTED_DOC)
-#define SCAN_HEURISTIC_PARTITION_INTXN          (ctx->options->heuristic & CL_SCAN_HEURISTIC_PARTITION_INTXN)
-#define SCAN_HEURISTIC_STRUCTURED               (ctx->options->heuristic & CL_SCAN_HEURISTIC_STRUCTURED)
-#define SCAN_HEURISTIC_STRUCTURED_SSN_NORMAL    (ctx->options->heuristic & CL_SCAN_HEURISTIC_STRUCTURED_SSN_NORMAL)
-#define SCAN_HEURISTIC_STRUCTURED_SSN_STRIPPED  (ctx->options->heuristic & CL_SCAN_HEURISTIC_STRUCTURED_SSN_STRIPPED)
+#define SCAN_HEURISTIC_BROKEN (ctx->options->heuristic & CL_SCAN_HEURISTIC_BROKEN)
+#define SCAN_HEURISTIC_EXCEEDS_MAX (ctx->options->heuristic & CL_SCAN_HEURISTIC_EXCEEDS_MAX)
+#define SCAN_HEURISTIC_PHISHING_SSL_MISMATCH (ctx->options->heuristic & CL_SCAN_HEURISTIC_PHISHING_SSL_MISMATCH)
+#define SCAN_HEURISTIC_PHISHING_CLOAK (ctx->options->heuristic & CL_SCAN_HEURISTIC_PHISHING_CLOAK)
+#define SCAN_HEURISTIC_MACROS (ctx->options->heuristic & CL_SCAN_HEURISTIC_MACROS)
+#define SCAN_HEURISTIC_ENCRYPTED_ARCHIVE (ctx->options->heuristic & CL_SCAN_HEURISTIC_ENCRYPTED_ARCHIVE)
+#define SCAN_HEURISTIC_ENCRYPTED_DOC (ctx->options->heuristic & CL_SCAN_HEURISTIC_ENCRYPTED_DOC)
+#define SCAN_HEURISTIC_PARTITION_INTXN (ctx->options->heuristic & CL_SCAN_HEURISTIC_PARTITION_INTXN)
+#define SCAN_HEURISTIC_STRUCTURED (ctx->options->heuristic & CL_SCAN_HEURISTIC_STRUCTURED)
+#define SCAN_HEURISTIC_STRUCTURED_SSN_NORMAL (ctx->options->heuristic & CL_SCAN_HEURISTIC_STRUCTURED_SSN_NORMAL)
+#define SCAN_HEURISTIC_STRUCTURED_SSN_STRIPPED (ctx->options->heuristic & CL_SCAN_HEURISTIC_STRUCTURED_SSN_STRIPPED)
 
-#define SCAN_MAIL_PARTIAL_MESSAGE               (ctx->options->mail & CL_SCAN_MAIL_PARTIAL_MESSAGE)
+#define SCAN_MAIL_PARTIAL_MESSAGE (ctx->options->mail & CL_SCAN_MAIL_PARTIAL_MESSAGE)
 
-#define SCAN_DEV_COLLECT_SHA                    (ctx->options->dev & CL_SCAN_DEV_COLLECT_SHA)
-#define SCAN_DEV_COLLECT_PERF_INFO              (ctx->options->dev & CL_SCAN_DEV_COLLECT_PERFORMANCE_INFO)
+#define SCAN_DEV_COLLECT_SHA (ctx->options->dev & CL_SCAN_DEV_COLLECT_SHA)
+#define SCAN_DEV_COLLECT_PERF_INFO (ctx->options->dev & CL_SCAN_DEV_COLLECT_PERFORMANCE_INFO)
 
 /* based on macros from A. Melnikoff */
 #define cbswap16(v) (((v & 0xff) << 8) | (((v) >> 8) & 0xff))
-#define cbswap32(v) ((((v) & 0x000000ff) << 24) | (((v) & 0x0000ff00) << 8) | \
-		    (((v) & 0x00ff0000) >> 8)  | (((v) & 0xff000000) >> 24))
-#define cbswap64(v) ((((v) & 0x00000000000000ffULL) << 56) | \
-		     (((v) & 0x000000000000ff00ULL) << 40) | \
-		     (((v) & 0x0000000000ff0000ULL) << 24) | \
-		     (((v) & 0x00000000ff000000ULL) <<  8) | \
-		     (((v) & 0x000000ff00000000ULL) >>  8) | \
-		     (((v) & 0x0000ff0000000000ULL) >> 24) | \
-		     (((v) & 0x00ff000000000000ULL) >> 40) | \
-		     (((v) & 0xff00000000000000ULL) >> 56))
+#define cbswap32(v) ((((v)&0x000000ff) << 24) | (((v)&0x0000ff00) << 8) | \
+                     (((v)&0x00ff0000) >> 8) | (((v)&0xff000000) >> 24))
+#define cbswap64(v) ((((v)&0x00000000000000ffULL) << 56) | \
+                     (((v)&0x000000000000ff00ULL) << 40) | \
+                     (((v)&0x0000000000ff0000ULL) << 24) | \
+                     (((v)&0x00000000ff000000ULL) << 8) |  \
+                     (((v)&0x000000ff00000000ULL) >> 8) |  \
+                     (((v)&0x0000ff0000000000ULL) >> 24) | \
+                     (((v)&0x00ff000000000000ULL) >> 40) | \
+                     (((v)&0xff00000000000000ULL) >> 56))
 
 #ifndef HAVE_ATTRIB_PACKED
 #define __attribute__(x)
@@ -549,18 +546,18 @@ extern int have_rar;
 #endif
 
 union unaligned_64 {
-	uint64_t una_u64;
-	int64_t una_s64;
+    uint64_t una_u64;
+    int64_t una_s64;
 } __attribute__((packed));
 
 union unaligned_32 {
-	uint32_t una_u32;
-	int32_t una_s32;
+    uint32_t una_u32;
+    int32_t una_s32;
 } __attribute__((packed));
 
 union unaligned_16 {
-	uint16_t una_u16;
-	int16_t una_s16;
+    uint16_t una_u16;
+    int16_t una_s16;
 } __attribute__((packed));
 
 struct unaligned_ptr {
@@ -575,69 +572,69 @@ struct unaligned_ptr {
 #endif
 
 #if WORDS_BIGENDIAN == 0
-    /* Little endian */
-    #define le16_to_host(v)	(v)
-    #define le32_to_host(v)	(v)
-    #define le64_to_host(v)	(v)
-    #define	be16_to_host(v)	cbswap16(v)
-    #define	be32_to_host(v)	cbswap32(v)
-    #define be64_to_host(v) cbswap64(v)
-    #define cli_readint64(buff) (((const union unaligned_64 *)(buff))->una_s64)
-    #define cli_readint32(buff) (((const union unaligned_32 *)(buff))->una_s32)
-    #define cli_readint16(buff) (((const union unaligned_16 *)(buff))->una_s16)
-    #define cli_writeint32(offset, value) (((union unaligned_32 *)(offset))->una_u32=(uint32_t)(value))
+/* Little endian */
+#define le16_to_host(v) (v)
+#define le32_to_host(v) (v)
+#define le64_to_host(v) (v)
+#define be16_to_host(v) cbswap16(v)
+#define be32_to_host(v) cbswap32(v)
+#define be64_to_host(v) cbswap64(v)
+#define cli_readint64(buff) (((const union unaligned_64 *)(buff))->una_s64)
+#define cli_readint32(buff) (((const union unaligned_32 *)(buff))->una_s32)
+#define cli_readint16(buff) (((const union unaligned_16 *)(buff))->una_s16)
+#define cli_writeint32(offset, value) (((union unaligned_32 *)(offset))->una_u32 = (uint32_t)(value))
 #else
-    /* Big endian */
-    #define	le16_to_host(v)	cbswap16(v)
-    #define	le32_to_host(v)	cbswap32(v)
-    #define le64_to_host(v) cbswap64(v)
-    #define be16_to_host(v)	(v)
-    #define be32_to_host(v)	(v)
-    #define be64_to_host(v)	(v)
+/* Big endian */
+#define le16_to_host(v) cbswap16(v)
+#define le32_to_host(v) cbswap32(v)
+#define le64_to_host(v) cbswap64(v)
+#define be16_to_host(v) (v)
+#define be32_to_host(v) (v)
+#define be64_to_host(v) (v)
 
-    static inline int64_t cli_readint64(const void *buff)
-    {
-        int64_t ret;
-        ret = (int64_t)((const char *)buff)[0] & 0xff;
-        ret |= (int64_t)(((const char *)buff)[1] & 0xff) << 8;
-        ret |= (int64_t)(((const char *)buff)[2] & 0xff) << 16;
-        ret |= (int64_t)(((const char *)buff)[3] & 0xff) << 24;
+static inline int64_t cli_readint64(const void *buff)
+{
+    int64_t ret;
+    ret = (int64_t)((const char *)buff)[0] & 0xff;
+    ret |= (int64_t)(((const char *)buff)[1] & 0xff) << 8;
+    ret |= (int64_t)(((const char *)buff)[2] & 0xff) << 16;
+    ret |= (int64_t)(((const char *)buff)[3] & 0xff) << 24;
 
-        ret |= (int64_t)(((const char *)buff)[4] & 0xff) << 32;
-        ret |= (int64_t)(((const char *)buff)[5] & 0xff) << 40;
-        ret |= (int64_t)(((const char *)buff)[6] & 0xff) << 48;
-        ret |= (int64_t)(((const char *)buff)[7] & 0xff) << 56;
-        return ret;
-    }
+    ret |= (int64_t)(((const char *)buff)[4] & 0xff) << 32;
+    ret |= (int64_t)(((const char *)buff)[5] & 0xff) << 40;
+    ret |= (int64_t)(((const char *)buff)[6] & 0xff) << 48;
+    ret |= (int64_t)(((const char *)buff)[7] & 0xff) << 56;
+    return ret;
+}
 
-    static inline int32_t cli_readint32(const void *buff)
-    {
-        int32_t ret;
-        ret = (int32_t)((const char *)buff)[0] & 0xff;
-        ret |= (int32_t)(((const char *)buff)[1] & 0xff) << 8;
-        ret |= (int32_t)(((const char *)buff)[2] & 0xff) << 16;
-        ret |= (int32_t)(((const char *)buff)[3] & 0xff) << 24;
-        return ret;
-    }
+static inline int32_t cli_readint32(const void *buff)
+{
+    int32_t ret;
+    ret = (int32_t)((const char *)buff)[0] & 0xff;
+    ret |= (int32_t)(((const char *)buff)[1] & 0xff) << 8;
+    ret |= (int32_t)(((const char *)buff)[2] & 0xff) << 16;
+    ret |= (int32_t)(((const char *)buff)[3] & 0xff) << 24;
+    return ret;
+}
 
-    static inline int16_t cli_readint16(const void *buff)
-    {
-        int16_t ret;
-        ret = (int16_t)((const char *)buff)[0] & 0xff;
-        ret |= (int16_t)(((const char *)buff)[1] & 0xff) << 8;
-        return ret;
-    }
+static inline int16_t cli_readint16(const void *buff)
+{
+    int16_t ret;
+    ret = (int16_t)((const char *)buff)[0] & 0xff;
+    ret |= (int16_t)(((const char *)buff)[1] & 0xff) << 8;
+    return ret;
+}
 
-    static inline void cli_writeint32(void *offset, uint32_t value)
-    {
-        ((char *)offset)[0] = value & 0xff;
-        ((char *)offset)[1] = (value & 0xff00) >> 8;
-        ((char *)offset)[2] = (value & 0xff0000) >> 16;
-        ((char *)offset)[3] = (value & 0xff000000) >> 24;
-    }
+static inline void cli_writeint32(void *offset, uint32_t value)
+{
+    ((char *)offset)[0] = value & 0xff;
+    ((char *)offset)[1] = (value & 0xff00) >> 8;
+    ((char *)offset)[2] = (value & 0xff0000) >> 16;
+    ((char *)offset)[3] = (value & 0xff000000) >> 24;
+}
 #endif
 
-int cli_append_virus(cli_ctx *ctx, const char *virname);
+cl_error_t cli_append_virus(cli_ctx *ctx, const char *virname);
 const char *cli_get_last_virus(const cli_ctx *ctx);
 const char *cli_get_last_virus_str(const cli_ctx *ctx);
 void cli_virus_found_cb(cli_ctx *ctx);
@@ -648,18 +645,18 @@ size_t cli_get_container_size(cli_ctx *ctx, int index);
 cli_file_t cli_get_container_intermediate(cli_ctx *ctx, int index);
 
 /* used by: spin, yc (C) aCaB */
-#define __SHIFTBITS(a) (sizeof(a)<<3)
-#define __SHIFTMASK(a) (__SHIFTBITS(a)-1)
-#define CLI_ROL(a,b) a = ( a << ((b) & __SHIFTMASK(a)) ) | ( a >> ((__SHIFTBITS(a) - (b)) & __SHIFTMASK(a)) )
-#define CLI_ROR(a,b) a = ( a >> ((b) & __SHIFTMASK(a)) ) | ( a << ((__SHIFTBITS(a) - (b)) & __SHIFTMASK(a)) )
+#define __SHIFTBITS(a) (sizeof(a) << 3)
+#define __SHIFTMASK(a) (__SHIFTBITS(a) - 1)
+#define CLI_ROL(a, b) a = (a << ((b)&__SHIFTMASK(a))) | (a >> ((__SHIFTBITS(a) - (b)) & __SHIFTMASK(a)))
+#define CLI_ROR(a, b) a = (a >> ((b)&__SHIFTMASK(a))) | (a << ((__SHIFTBITS(a) - (b)) & __SHIFTMASK(a)))
 
 /* Implementation independent sign-extended signed right shift */
 #ifdef HAVE_SAR
-#define CLI_SRS(n,s) ((n)>>(s))
+#define CLI_SRS(n, s) ((n) >> (s))
 #else
-#define CLI_SRS(n,s) ((((n)>>(s)) ^ (1<<(sizeof(n)*8-1-s))) - (1<<(sizeof(n)*8-1-s)))
+#define CLI_SRS(n, s) ((((n) >> (s)) ^ (1 << (sizeof(n) * 8 - 1 - s))) - (1 << (sizeof(n) * 8 - 1 - s)))
 #endif
-#define CLI_SAR(n,s) n = CLI_SRS(n,s)
+#define CLI_SAR(n, s) n = CLI_SRS(n, s)
 
 #ifdef __GNUC__
 void cli_warnmsg(const char *str, ...) __attribute__((format(printf, 1, 2)));
@@ -674,12 +671,12 @@ void cli_errmsg(const char *str, ...);
 #endif
 
 #ifdef __GNUC__
-void cli_infomsg(const cli_ctx* ctx, const char *fmt, ...) __attribute__((format(printf, 2, 3)));
+void cli_infomsg(const cli_ctx *ctx, const char *fmt, ...) __attribute__((format(printf, 2, 3)));
 #else
-void cli_infomsg(const cli_ctx* ctx, const char *fmt, ...);
+void cli_infomsg(const cli_ctx *ctx, const char *fmt, ...);
 #endif
 
-void cli_logg_setup(const cli_ctx* ctx);
+void cli_logg_setup(const cli_ctx *ctx);
 void cli_logg_unsetup(void);
 
 /* tell compiler about branches that are very rarely taken,
@@ -700,7 +697,7 @@ void cli_logg_unsetup(void);
 #define always_inline inline
 #endif
 
-#if defined (__GNUC__) && ((__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
+#if defined(__GNUC__) && ((__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
 #define __hot__ __attribute__((hot))
 #else
 #define __hot__
@@ -719,18 +716,25 @@ void cli_dbgmsg_internal(const char *str, ...);
 #endif
 
 #ifdef _WIN32
-static inline int cli_getpagesize(void) {
+static inline int cli_getpagesize(void)
+{
     SYSTEM_INFO si;
     GetSystemInfo(&si);
     return si.dwPageSize;
 }
 #else /* ! _WIN32 */
 #if HAVE_SYSCONF_SC_PAGESIZE
-static inline int cli_getpagesize(void) { return sysconf(_SC_PAGESIZE); }
+static inline int cli_getpagesize(void)
+{
+    return sysconf(_SC_PAGESIZE);
+}
 #define HAVE_CLI_GETPAGESIZE 1
 #else
 #if HAVE_GETPAGESIZE
-static inline int cli_getpagesize(void) { return getpagesize(); }
+static inline int cli_getpagesize(void)
+{
+    return getpagesize();
+}
 #define HAVE_CLI_GETPAGESIZE 1
 #endif /* HAVE_GETPAGESIZE */
 #endif /* HAVE_SYSCONF_SC_PAGESIZE */
@@ -745,8 +749,8 @@ int cli_rmdirs(const char *dirname);
 char *cli_hashstream(FILE *fs, unsigned char *digcpy, int type);
 char *cli_hashfile(const char *filename, int type);
 int cli_unlink(const char *pathname);
-int cli_readn(int fd, void *buff, unsigned int count);
-int cli_writen(int fd, const void *buff, unsigned int count);
+size_t cli_readn(int fd, void *buff, size_t count);
+size_t cli_writen(int fd, const void *buff, size_t count);
 const char *cli_gettmpdir(void);
 
 /**
@@ -775,7 +779,7 @@ char *cli_genfname(const char *prefix);
  * @param dir 	 Alternative temp directory. (optional)
  * @return char* filename or NULL.
  */
-char* cli_gentemp_with_prefix(const char* dir, const char* prefix);
+char *cli_gentemp_with_prefix(const char *dir, const char *prefix);
 
 /**
  * @brief Generate a full tempfile filepath with a random MD5 hash.
@@ -806,7 +810,7 @@ cl_error_t cli_gentempfd(const char *dir, char **name, int *fd);
  * @param[out] fd    File descriptor of open temp file.
  * @return cl_error_t CL_SUCCESS, CL_ECREAT, or CL_EMEM.
  */
-cl_error_t cli_gentempfd_with_prefix(const char* dir, char* prefix, char** name, int* fd);
+cl_error_t cli_gentempfd_with_prefix(const char *dir, char *prefix, char **name, int *fd);
 
 unsigned int cli_rndnum(unsigned int max);
 int cli_filecopy(const char *src, const char *dest);
@@ -814,32 +818,32 @@ bitset_t *cli_bitset_init(void);
 void cli_bitset_free(bitset_t *bs);
 int cli_bitset_set(bitset_t *bs, unsigned long bit_offset);
 int cli_bitset_test(bitset_t *bs, unsigned long bit_offset);
-const char* cli_ctime(const time_t *timep, char *buf, const size_t bufsize);
+const char *cli_ctime(const time_t *timep, char *buf, const size_t bufsize);
 void cli_check_blockmax(cli_ctx *, int);
 cl_error_t cli_checklimits(const char *, cli_ctx *, unsigned long, unsigned long, unsigned long);
 cl_error_t cli_updatelimits(cli_ctx *, unsigned long);
 unsigned long cli_getsizelimit(cli_ctx *, unsigned long);
 int cli_matchregex(const char *str, const char *regex);
 void cli_qsort(void *a, size_t n, size_t es, int (*cmp)(const void *, const void *));
-void cli_qsort_r(void *a, size_t n, size_t es, int (*cmp)(const void*, const void *, const void *), void *arg);
+void cli_qsort_r(void *a, size_t n, size_t es, int (*cmp)(const void *, const void *, const void *), void *arg);
 cl_error_t cli_checktimelimit(cli_ctx *ctx);
 cl_error_t cli_append_possibly_unwanted(cli_ctx *ctx, const char *virname);
 
 /* symlink behaviour */
 #define CLI_FTW_FOLLOW_FILE_SYMLINK 0x01
-#define CLI_FTW_FOLLOW_DIR_SYMLINK  0x02
+#define CLI_FTW_FOLLOW_DIR_SYMLINK 0x02
 
 /* if the callback needs the stat */
-#define CLI_FTW_NEED_STAT	    0x04
+#define CLI_FTW_NEED_STAT 0x04
 
 /* remove leading/trailing slashes */
-#define CLI_FTW_TRIM_SLASHES	    0x08
+#define CLI_FTW_TRIM_SLASHES 0x08
 #define CLI_FTW_STD (CLI_FTW_NEED_STAT | CLI_FTW_TRIM_SLASHES)
 
 enum cli_ftw_reason {
     visit_file,
     visit_directory_toplev, /* this is a directory at toplevel of recursion */
-    error_mem, /* recommended to return CL_EMEM */
+    error_mem,              /* recommended to return CL_EMEM */
     /* recommended to return CL_SUCCESS below */
     error_stat,
     warning_skipped_link,
@@ -884,7 +888,7 @@ typedef int (*cli_ftw_pathchk)(const char *path, struct cli_ftw_cbdata *data);
  */
 int cli_ftw(char *base, int flags, int maxdepth, cli_ftw_cb callback, struct cli_ftw_cbdata *data, cli_ftw_pathchk pathchk);
 
-const char *cli_strerror(int errnum, char* buf, size_t len);
+const char *cli_strerror(int errnum, char *buf, size_t len);
 
 /**
  * @brief   Attempt to get a filename from an open file descriptor.
@@ -896,6 +900,6 @@ const char *cli_strerror(int errnum, char* buf, size_t len);
  * @param[out] filepath  Will be set to file path if found, or NULL.
  * @return cl_error_t    CL_SUCCESS if found, else an error code.
  */
-cl_error_t cli_get_filepath_from_filedesc(int desc, char** filepath);
+cl_error_t cli_get_filepath_from_filedesc(int desc, char **filepath);
 
 #endif
