@@ -1,11 +1,11 @@
 /*
- *  Copyright (C) 2015, 2018 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
- *  Copyright (C) 2007-2008 Sourcefire, Inc.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Nigel Horne
- * 
+ *
  *  Summary: Extract files compressed with TAR compression format.
- * 
+ *
  *  Acknowledgements: ClamAV untar code is based on a public domain minitar utility
  *                    by Charles G. Waldman.
  *
@@ -29,6 +29,6 @@
 
 #include "others.h"
 
-int cli_untar(const char *dir, unsigned int posix, cli_ctx *ctx);
+cl_error_t cli_untar(const char *dir, unsigned int posix, cli_ctx *ctx);
 
 #endif
